==> adyen-java-api-library-2.7.0-sources.jar: com/adyen/model/marketpay/notification/AccountHolderVerificationNotification.java <==
/*
 *                       ######
 *                       ######
 * ############    ####( ######  #####. ######  ############   ############
 * #############  #####( ######  #####. ######  #############  #############
 *        ######  #####( ######  #####. ######  #####  ######  #####  ######
 * ###### ######  #####( ######  #####. ######  #####  #####   #####  ######
 * ###### ######  #####( ######  #####. ######  #####          #####  ######
 * #############  #############  #############  #############  #####  ######
 *  ############   ############  #############   ############  #####  ######
 *                                      ######
 *                               #############
 *                               ############
 *
 * Adyen Java API Library
 *
 * Copyright (c) 2017 Adyen B.V.
 * This file is open source and available under the MIT license.
 * See the LICENSE file for more info.
 */

package com.adyen.model.marketpay.notification;

import com.google.gson.annotations.SerializedName;

public class AccountHolderVerificationNotification extends GenericNotification {
    @SerializedName("content")
    private AccountHolderVerificationContent content;

    public AccountHolderVerificationContent getContent() {
        return content;
    }

    public void setContent(AccountHolderVerificationContent content) {
        this.content = content;
    }

    @Override
    public String toString() {
        return "AccountHolderVerificationNotification{" + "content=" + content + '}';
    }
}

==> adyen-java-api-library-13.0.0-sources.jar: com/adyen/model/marketpay/notification/AccountHolderVerificationNotification.java <==
/*
 *                       ######
 *                       ######
 * ############    ####( ######  #####. ######  ############   ############
 * #############  #####( ######  #####. ######  #############  #############
 *        ######  #####( ######  #####. ######  #####  ######  #####  ######
 * ###### ######  #####( ######  #####. ######  #####  #####   #####  ######
 * ###### ######  #####( ######  #####. ######  #####          #####  ######
 * #############  #############  #############  #############  #####  ######
 *  ############   ############  #############   ############  #####  ######
 *                                      ######
 *                               #############
 *                               ############
 *
 * Adyen Java API Library
 *
 * Copyright (c) 2017 Adyen B.V.
 * This file is open source and available under the MIT license.
 * See the LICENSE file for more info.
 */

package com.adyen.model.marketpay.notification;

import com.google.gson.annotations.SerializedName;

public class AccountHolderVerificationNotification extends GenericNotification {
    @SerializedName("content")
    private AccountHolderVerificationContent content;

    public AccountHolderVerificationContent getContent() {
        return content;
    }

    public void setContent(AccountHolderVerificationContent content) {
        this.content = content;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("AccountHolderVerificationNotification{");
        sb.append("content=").append(content);
        sb.append('}');
        return sb.toString();
    }
}
